<?php
/*
 * copyright (c) 2010 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of WordPress Amazon Associate Plugin.
 *
 * WordPress Amazon Associate is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * WordPress Amazon Associate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress Amazon Associate.
 * If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * Base Amazon Widget
 *
 * This file contains the class Widget_MDBitz_Base
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @package com.mdbitz.wordpress.amazon_associate.Widget.MDBitz
 */

/**
 * Widget_MDBitz_Base is an extension of the WP_Widget with form input methods
 *
 * @package com.mdbitz.wordpress.amazon_associate.Widget.Amazon
 */
class Widget_MDBitz_Base extends WP_Widget {

    /**
     * returns HTML checkbox input
     *
     * @param String $id input id and name
     * @param String $value is checked
     * @return String
     */
    public function checkbox($id, $value = false) {
        return '<input class="checkbox" type="checkbox" value="True" id="' . $this->get_field_id($id) . '" name="' . $this->get_field_name($id) . '" ' . ( ($value == true) ? "checked" : "" ) . ' />';
    }

    /**
     * returns HTML checkbox input with label
     *
     * @param String $id input id and name
     * @param String $value is checked
     * @return String
     */
    public function checkboxWithLabel( $label, $id, $value = false) {
        return $this->checkbox( $id, $value ) . '<label for="' . $this->get_field_id($id) . '" >' . $label .'</label><br/>';
    }

    /**
     * returns HTML text input
     *
     * @param String $id input id and name
     * @param String $value input value
     * @return String
     */
    public function textinput($id, $value) {
        return '<input class="widefat" type="text" id="' . $this->get_field_id($id) . '" name="' . $this->get_field_name($id) . '" size="30" value="' . $value . '"/>';
    }

    /**
     * returns HTML text input with label
     *
     * @param String $id input id and name
     * @param String $value input value
     * @return String
     */
    public function textinputWithLabel( $label, $id, $value) {
        return '<label for="' . $this->get_field_id($id) . '" >' . $label . $this->textinput( $id, $value ) . '</label>';
    }

    /**
     * returns HTML select input
     *
     * @param String $id input id and name
     * @param array $options Array of Options
     * @param String $selected value selected option value
     * @return String
     */
    public function select($id, $options, $selected_value, $etc = "") {
        $output_txt = '<select class="widefat" ' . $etc . ' name="' . $this->get_field_name($id) . '" id="' . $this->get_field_id($id) . '">';
        foreach ($options as $option_value => $option_text) {
            $selected_txt = '';
            if ($selected_value == $option_value) {
                $selected_txt = ' SELECTED';
            }
            if ($option_text == '') {
                $option_text = $option_value;
            }
            $output_txt .= '<option value="' . $option_value . '"' . $selected_txt . '>' . $option_text . '</option>';
        }
        $output_txt .= '</select>';
        return $output_txt;
    }

    /**
     * returns HTML select input with label
     *
     * @param String $id input id and name
     * @param array $options Array of Options
     * @param String $selected value selected option value
     * @return String
     */
    public function selectWithLabel( $label, $id, $options, $selected_value, $etc = "") {
        return '<label for="' . $this->get_field_id($id) . '" >' . $label . $this->select($id, $options, $selected_value, $etc) . '</label>';
    }
    
} // class Widget_MDBitz_Base